from setuptools import setup
from sys import version_info


if version_info[0] == 2:
    dep_rpy2 = 'rpy2==2.8'
if version_info[0] == 3:
    dep_rpy2 = 'rpy2>=2.9.1'


setup(name='multipipsa',
        version='4.0.6',
        description='Run Protein Interaction Properties comparisons on multiple sites of a protein (all CA atoms) and calculate scores according to Tong, Wade and Bruce, Proteins 2016; 84:1844-1858',
        url='http://pipsa.h-its.org',
        author='Molecular and Cellular Modeling Group at Heidelberg Institute for Theoretical Sciences',
        author_email='mcmsoft@h-its.org',
        packages=['multipipsa'],
        license='EUPL 1.2 https://eupl.eu/',
        platforms=['LINUX'],
        long_description='PIPSA is a tool for the comparison of the electrostatic interaction properties of proteins. It permits the classification of proteins according to their interaction properties. The multipipsa python wrapper is designed to run Protein Interaction Properties comparisons on multiple sites of a protein (all CA atoms) and calculate scores according to Tong, Wade and Bruce, Proteins 2016; 84:1844-1858',
        download_url='https://pipsa.h-its.org/',
        package_data={'multipipsa':['data/*']},
        categories=['Development Status :: 5 - Production/Stable',
                    'Environment :: Console',
                    'Intended Audience :: Science/Research',
                    'License :: OSI Approved :: European Union Public Licence 1.2 (EUPL 1.2)',
                    'Natural Language :: English',
                    'Operating System :: POSIX :: Linux',
                    'Topic :: Scientific/Engineering :: Bio-Informatics'
                    ],
        install_requires=[
            'biopython',
            'numpy',
            dep_rpy2,
            'griddataformats',
            'pandas',
            'enum34',
            'tzlocal'
        ],
        include_package_data=True,
        zip_safe=False)
